<?php

namespace AdScale\API;

use AdScale\Helpers\Helper;
use AdScale\Helpers\Logger;


class API_Manager {
	
	
	/**
	 * Get google_site_verification from API and save it
	 *
	 * @return bool|string
	 */
	public static function process_google_verification_code() {
		$request_template = Helper::getConfigSetting( 'GVC_request_tpl', '' );
		if ( ! $request_template ) {
			return false;
		}
		
		$code = self::get_tag_value( $request_template );
		
		if ( $code ) {
			Helper::saveGVCode( $code );
			
			return $code;
		}
		
		return false;
	}
	
	
	
	public static function process_facebook_verification_code() {
		$request_template = Helper::getConfigSetting( 'FVC_request_tpl', '' );
		if ( ! $request_template ) {
			return false;
		}
		
		$code = self::get_tag_value( $request_template );
		
		if ( $code ) {
			Helper::saveFVCode( $code );
			
			return $code;
		}
		
		return false;
	}
	
	
	
	
	public static function get_tag_value( $request_template ) {
		$request_url = str_replace( '%SHOP_DOMAIN%', Helper::getShopDomain(), $request_template );
		
		$result = API_Process::process( $request_url, 'sv_code' );
		
		$is_success = ! empty( $result['data']['success'] ) && '1' === $result['data']['success'];
		$code       = ! empty( $result['data']['tag'] ) ? $result['data']['tag'] : '';
		
		if ( $is_success && $code ) {
			return $code;
		}
		
		return false;
	}
	
	
	
	
	public static function process_heartbeat() {
		
		$request_template = Helper::getConfigSetting( 'heartbeat/request_tpl', '' );
		if ( ! $request_template ) {
			return false;
		}
		
		$request_url = str_replace( '%SHOP_DOMAIN%', Helper::getShopDomain(), $request_template );
		$result      = API_Process::process( $request_url, 'process_heartbeat' );
		$is_success  = ! empty( $result['data']['success'] ) && '1' === $result['data']['success'];
		Logger::log( $is_success, 'is_success: ', 'process_heartbeat' );
		
		return $is_success;
	}
	
	
	
	
	public static function process_proxy() {
		$params              = $_GET;
		$params['shop_host'] = Helper::getShopDomain();
		
		$proxyEndpoint = Helper::getProxyEndpoint();
		if ( ( ! $proxyEndpoint ) || count( $params ) >= 100 ) {
			return false;
		}
		
		$request_url = $proxyEndpoint . '?' . http_build_query( $params, null, '&', PHP_QUERY_RFC3986 );
		$result      = API_Process::process( $request_url, 'processProxy', false );
		
		return $result['data_raw'];
	}
	
	
	
	
	public static function process_module_event( $request_template, $request_event_name ) {
		
		if ( ! $request_template || ! $request_event_name ) {
			return false;
		}
		
		$request_url = str_replace(
			[
				'%SHOP_DOMAIN%',
				'%EVENT%',
				'%PLATFORM%',
				'%EMAIL%',
				'%MODE%',
			],
			[
				Helper::getShopDomain(),
				$request_event_name,
				Helper::getConfigSetting( 'shop/platform', 'woo' ),
				Helper::getResolvedActivationEmail(),
				Helper::getMode(),
			],
			$request_template
		);
		$result      = API_Process::process( $request_url, 'Events' );
		$is_success  = ! empty( $result['success'] ) && true === $result['success'];
		
		return $is_success;
	}
}
