<?php
/**
 * Abstract Class for creating Singleton Classes
 *
 */

namespace AdScale;

defined( 'ABSPATH' ) || exit; // Exit if accessed directly

/**
 * Class AbstractSingleton
 *
 */
abstract class AbstractSingleton {
	/**
	 * Call this method to get singleton
	 */
	public static function instance() {
		static $instance = false;
		if ( false === $instance ) {
			$instance = new static();
		}

		return $instance;
	}

	/**
	 * Make constructor private, so nobody can call "new Class".
	 */
	protected function __construct() {
	}

	/**
	 * Make clone magic method private, so nobody can clone instance.
	 */
	private function __clone() {
	}
}
