<?php

namespace AdScale\Handlers;

use AdScale\Helpers\Helper;

defined('ABSPATH') || exit; // Exit if accessed directly


class Settings
{


    public static $options_page_hook;


    public static function menu()
    {

        self::$options_page_hook = add_submenu_page(
            'woocommerce',
            __('AdScale', 'adscale'),
            __('AdScale', 'adscale'),
            'manage_woocommerce',
            'wc_plugin_adscale_settings',
            [self::class, 'settings_page']
        );


    }


    public static function settings_page()
    {
        GoToAdscale::redirect();
        include ADSCALE_PLUGIN_DIR . '/src/views/settings-page.php';
    }


    public static function settings_init()
    {

        register_setting(
            'wc_plugin_adscale_settings__main_group',
            'adscale__shop_domain',
            [self::class, 'sanitize__standard']
        );

        register_setting(
            'wc_plugin_adscale_settings__main_group',
            'adscale__gsv',
            [self::class, 'sanitize__standard']
        );


        register_setting(
            'wc_plugin_adscale_settings__main_group',
            'adscale__fdv',
            [self::class, 'sanitize__standard']
        );

        register_setting(
            'wc_plugin_adscale_settings__main_group',
            'adscale__optin_enabled',
            [self::class, 'sanitize__standard']
        );

        register_setting(
            'wc_plugin_adscale_settings__main_group',
            'adscale__optin_checked_by_default',
            [self::class, 'sanitize__standard']
        );

        register_setting(
            'wc_plugin_adscale_settings__main_group',
            'adscale__optin_position',
            [self::class, 'sanitize__standard']
        );
        register_setting(
            'wc_plugin_adscale_settings__main_group',
            'adscale__optin_message',
            [self::class, 'sanitize__standard']
        );


        add_settings_section(
            'wc_plugin_adscale_settings__main_section',
            '',
            [self::class, 'main_section_desc_view'],
            'wc_plugin_adscale_settings'
        );


        add_settings_field(
            'wc_plugin_adscale_settings__shop_domain',
            __('Shop domain (without protocol and www)', 'adscale'),
            [self::class, 'setting_view__shop_domain'],
            'wc_plugin_adscale_settings',
            'wc_plugin_adscale_settings__main_section',
            [
                'class' => 'hidden-label',
                'tag_id' => 'adscale__shop_domain_id',
                'tag_name' => 'adscale__shop_domain',
                'label_for' => 'adscale__shop_domain_id',
            ]
        );


        add_settings_field(
            'wc_plugin_adscale_settings__gsv',
            __('Google site verification code', 'adscale'),
            [self::class, 'setting_view__gsv'],
            'wc_plugin_adscale_settings',
            'wc_plugin_adscale_settings__main_section',
            [
                'class' => 'hidden-label',
                'tag_id' => 'adscale__gsv_id',
                'tag_name' => 'adscale__gsv',
                'label_for' => 'adscale__gsv_id',
            ]
        );


        add_settings_field(
            'wc_plugin_adscale_settings__fdv',
            __('Facebook domain verification code', 'adscale'),
            [self::class, 'setting_view__fdv'],
            'wc_plugin_adscale_settings',
            'wc_plugin_adscale_settings__main_section',
            [
                'class' => 'hidden-label',
                'tag_id' => 'adscale__fdv_id',
                'tag_name' => 'adscale__fdv',
                'label_for' => 'adscale__fdv_id',
            ]
        );
        add_settings_field(
            'wc_plugin_adscale__optin_enabled',
            __('Opt-in Checkbox Setup', 'adscale'),
            [self::class, 'setting_view__optin_enabled'],
            'wc_plugin_adscale_settings',
            'wc_plugin_adscale_settings__main_section',
            [
                'class' => 'hidden-label',
                'tag_id' => 'adscale__optin_enabled_id',
                'tag_name' => 'adscale__optin_enabled',
                'label_for' => 'adscale__optin_enabled_id',

            ]

        );
        add_settings_field(
            'wc_plugin_adscale__optin_checked_by_default_id',
            __('Choose how you want the opt-in checkbox to appear at checkout', 'adscale'),
            [self::class, 'setting_view__optin_checked_by_default_id'],
            'wc_plugin_adscale_settings',
            'wc_plugin_adscale_settings__main_section',
            [
                'class' => 'hidden-label',
                'tag_id' => 'adscale__optin_checked_by_default_id',
                'tag_name' => 'adscale__optin_checked_by_default',
                'label_for' => 'adscale__optin_checked_by_default_id',
            ]
        );
        add_settings_field(
            'wc_plugin_adscale__optin_message',
            __('Opt-In Checkbox Text', 'adscale'),
            [self::class, 'setting_view__optin_message'],
            'wc_plugin_adscale_settings',
            'wc_plugin_adscale_settings__main_section',
            [
                'class' => 'hidden-label',
                'tag_id' => 'adscale__optin_message_id',
                'tag_name' => 'adscale__optin_message',
                'label_for' => 'adscale__optin_message_id',
            ]
        );
        add_settings_field(
            'wc_plugin_adscale__optin_position',
            __('Opt-In Checkbox Position', 'adscale'),
            [self::class, 'setting_view__optin_position'],
            'wc_plugin_adscale_settings',
            'wc_plugin_adscale_settings__main_section',
            [
                'class' => 'hidden-label',
                'tag_id' => 'adscale__optin_position_id',
                'tag_name' => 'adscale__optin_position',
                'label_for' => 'adscale__optin_position_id',
            ]
        );


    }

    public static function main_section_desc_view()
    {
    }



    public static function setting_view__shop_domain($args)
    {

        $value = Helper::getShopDomain();

        echo '<h6 class="rows-item__title">' . __('Shop domain', 'adscale') . '</h6>
               <input type="text" class="regular-text" readonly
					 id="' . esc_attr($args['tag_id']) . '"
					 name="' . esc_attr($args['tag_name']) . '"
					 value="' . esc_attr($value) . '">
			   <br>
			   <p class="description"></p>';

    }


    public static function setting_view__gsv($args)
    {

        $value = Helper::getGVCode();

        echo '<h6 class="rows-item__title">' . __('Google site verification code', 'adscale') . '</h6>
                        <input type="text" class="regular-text" readonly
					 id="' . esc_attr($args['tag_id']) . '"
					 name="' . esc_attr($args['tag_name']) . '"
					 value="' . esc_attr($value) . '">
				 <br>
				 <p class="description"></p>';
    }


    public static function setting_view__fdv($args)
    {

        $value = Helper::getFVCode();

        echo '<h6 class="rows-item__title">' . __('Facebook domain verification code', 'adscale') . '</h6>
                <input type="text" class="regular-text" readonly
					 id="' . esc_attr($args['tag_id']) . '"
					 name="' . esc_attr($args['tag_name']) . '"
					 value="' . esc_attr($value) . '">
				 <br>
				 <p class="description"></p>';
    }

    public static function setting_view__optin_enabled($args)
    {
        $value = get_option($args['tag_name']) ?: false;

        echo '<h5>' . __('Opt-in Checkbox Setup', 'adscale') . '</h5>
             <div class="rows-item ios-toggle ios-toggle-reverse">
                 <input type="checkbox" name="' . $args['tag_name'] . '" ' . ($value ? ' checked ' : '') . '
                           id="' . $args['tag_id'] . '">
                 <label for="' . $args['tag_id'] . '" value="1"></label>
                <span class="label__checkbox checked">' . __("Show opt-in checkbox at checkout page", 'adscale') . '</span>
                <span class="label__checkbox unchecked">' . __("Hide opt-in checkbox at checkout page", 'adscale') . '</span>
             </div>';
        Settings::settings_notice();
    }

    public static function setting_view__optin_checked_by_default_id($args)
    {
        $value = get_option($args['tag_name']) ?: "";


        echo '<div class="rows-item hide-row adscale__show_checkbox-row" ' . Settings::styleOptInEnabled() . ' >
                <p class="adscale__show_checkbox__label">' . __('Choose how you want the opt-in checkbox to appear at checkout:', 'adscale') . '</p>
               <span class="adscale__show_checkbox__wrap"><input type="radio" class="radio-input" name="' . $args['tag_name'] . '" ' . (($value == "" || $value == 'on') ? ' checked ' : '') . '
                       id="' . $args['tag_id'] . '_on" value="on">
                <label for="' . $args['tag_id'] . '_on" class="label__checkbox"><span class="custom-radio"></span>
                     ' . __('Checked by default') . '</label></span> 
              <span class="adscale__show_checkbox__wrap"><input type="radio" class="radio-input" name="' . $args['tag_name'] . '" ' . (($value == 'off') ? ' checked ' : '') . '
                       id="' . $args['tag_id'] . '_off" value="off">
                <label for="' . $args['tag_id'] . '_off" class="label__checkbox"><span class="custom-radio"></span>
                    ' . __('Unchecked by default', 'adscale') . '  </label></span> 
              </div>';
    }

    public static function setting_view__optin_message($args)
    {
        $value = get_option($args['tag_name']) ?: __('I agree to receive marketing materials by sms or email', 'adscale');

        echo '<div class="rows-item hide-row" ' . Settings::styleOptInEnabled() . '>
                <h6 class="rows-item__title">' . __('Checkbox Text', 'adscale') . '</h6>
                <label for="' . $args['tag_id'] . '" class="adscale__text_checkbox_checkout__label">' . __('Enter the text that
                    appears next to the opt-in checkbox at checkout:', 'adscale') . '</label>
                <textarea rows="2" name="' . $args['tag_name'] . '" id="' . $args['tag_id'] . '" maxlength="150">' . $value . '</textarea>
                <div class="textarea-charecter">Characters <span class="count">54</span>/500</div>
            </div>';
    }

    public static function setting_view__optin_position($args)
    {
        $value = get_option($args['tag_name']) ?: "";
        $options_array = [
            'woocommerce_review_order_before_submit',
            'woocommerce_review_order_after_submit',
            'woocommerce_checkout_before_terms_and_conditions',
            'woocommerce_checkout_after_terms_and_conditions',
            'woocommerce_checkout_before_order_review',
            'woocommerce_checkout_after_order_review',
        ];
        $options = '';
        foreach ($options_array as $item) {
            $options .= '<option value="' . $item . '" ' . ($value == $item ? " selected " : "") . '>' . $item . '</option>';
        }

        echo '<div class="rows-item hide-row adscale__position-select-row" ' . Settings::styleOptInEnabled() . '>
                <h6 class="rows-item__title">' . __('Checkbox Position', 'adscale') . '</h6>
                <p>' . __('Select the position of the opt-in checkbox at checkout page:', 'adscale') . '</p>
                <select class="js-example-basic-single" name="' . $args['tag_name'] . '" id="' . $args['tag_id'] . '">
                     ' . $options . '
                </select>
              </div>';
    }

    public static function sanitize__standard($input)
    {
        return sanitize_text_field($input);
    }

    public static function settings_notice()
    {
        $otherPlugins = ['Mailchimp' => 'mailchimp-for-woocommerce/mailchimp-woocommerce.php'];

        foreach ($otherPlugins as $key => $field) {
            if (is_plugin_active($field)) {
                ?>
                <div class="notice-error rows-item hide-row" <?php echo Settings::styleOptInEnabled() ?> >
                    <svg width="20" height="18" viewBox="0 0 20 18" fill="none" xmlns="http://www.w3.org/2000/svg">
                        <path d="M10.0004 12.3332C9.83556 12.3332 9.67445 12.3821 9.5374 12.4737C9.40036 12.5652 9.29355 12.6954 9.23048 12.8477C9.16741 12.9999 9.1509 13.1675 9.18306 13.3291C9.21521 13.4908 9.29458 13.6393 9.41112 13.7558C9.52767 13.8724 9.67615 13.9517 9.8378 13.9839C9.99946 14.016 10.167 13.9995 10.3193 13.9365C10.4716 13.8734 10.6017 13.7666 10.6933 13.6295C10.7848 13.4925 10.8337 13.3314 10.8337 13.1666C10.8337 12.9456 10.7459 12.7336 10.5896 12.5773C10.4334 12.421 10.2214 12.3332 10.0004 12.3332ZM18.892 13.5582L12.1837 1.89157C11.9669 1.50283 11.6502 1.17903 11.2664 0.953625C10.8825 0.728217 10.4455 0.609375 10.0004 0.609375C9.55526 0.609375 9.11821 0.728217 8.73439 0.953625C8.35056 1.17903 8.03387 1.50283 7.81705 1.89157L1.15038 13.5582C0.926043 13.9366 0.805499 14.3674 0.800917 14.8073C0.796335 15.2471 0.907878 15.6803 1.12428 16.0633C1.34069 16.4462 1.6543 16.7653 2.03345 16.9883C2.4126 17.2112 2.84387 17.3302 3.28371 17.3332H16.717C17.1604 17.3376 17.597 17.224 17.982 17.004C18.367 16.784 18.6865 16.4656 18.9079 16.0814C19.1292 15.6972 19.2444 15.2611 19.2416 14.8177C19.2389 14.3743 19.1182 13.9396 18.892 13.5582ZM17.4504 15.2249C17.3773 15.3549 17.2708 15.4628 17.1418 15.5376C17.0128 15.6123 16.8661 15.6511 16.717 15.6499H3.28371C3.13464 15.6511 2.98796 15.6123 2.85898 15.5376C2.72999 15.4628 2.62342 15.3549 2.55038 15.2249C2.47724 15.0982 2.43873 14.9545 2.43873 14.8082C2.43873 14.662 2.47724 14.5182 2.55038 14.3916L9.21705 2.7249C9.28698 2.5884 9.39322 2.47385 9.52408 2.39385C9.65494 2.31386 9.80534 2.27153 9.95871 2.27153C10.1121 2.27153 10.2625 2.31386 10.3933 2.39385C10.5242 2.47385 10.6304 2.5884 10.7004 2.7249L17.4087 14.3916C17.4914 14.5164 17.5389 14.6613 17.5462 14.8108C17.5536 14.9604 17.5205 15.1092 17.4504 15.2416V15.2249ZM10.0004 5.66657C9.77937 5.66657 9.5674 5.75436 9.41112 5.91065C9.25484 6.06693 9.16705 6.27889 9.16705 6.4999V9.83323C9.16705 10.0542 9.25484 10.2662 9.41112 10.4225C9.5674 10.5788 9.77937 10.6666 10.0004 10.6666C10.2214 10.6666 10.4334 10.5788 10.5896 10.4225C10.7459 10.2662 10.8337 10.0542 10.8337 9.83323V6.4999C10.8337 6.27889 10.7459 6.06693 10.5896 5.91065C10.4334 5.75436 10.2214 5.66657 10.0004 5.66657Z"
                              fill="#FEF4F4"/>
                    </svg>
                    <p>
                        <?php esc_html_e('Please check opt-in configuration of other plugins (' . $key . ') to aviod double messages at checkout page.', ' adscale'); ?>
                    </p>
                </div>
                <?php
            }
        }

    }

    public static function styleOptInEnabled()
    {
        $optInEnabled = Helper::getOptInEnabled();
        return !$optInEnabled ? 'style="display:none"' : '';
    }

}