<?php

namespace AdScale\Helpers;

use AdScale\App;
use AdScale\API\API_Manager;

defined( 'ABSPATH' ) || exit; // Exit if accessed directly


class Helper {
	
	
	public static function is_product_page() {
		return function_exists( 'is_product' ) && is_product();
	}
	
	
	
	
	public static function is_order_received_endpoint() {
		return function_exists( 'is_wc_endpoint_url' ) && is_wc_endpoint_url( 'order-received' );
	}
	
	
	
	
	public static function is_order_received_page() {
		return function_exists( 'is_order_received_page' ) && is_order_received_page();
	}
	
	
	
	
	public static function get_product_id() {
		
		$product = function_exists( 'wc_get_product' ) ? wc_get_product() : 0;
		
		if ( ! is_object( $product ) || ! method_exists( $product, 'get_id' ) ) {
			return 0;
		}
		
		return (int) $product->get_id();
	}
	
	
	
	
	public static function get_product_value() {
		
		$product = function_exists( 'wc_get_product' ) ? wc_get_product() : 0;
		
		if ( ! is_object( $product ) || ! method_exists( $product, 'get_price' ) ) {
			return false;
		}
		
		return $product->get_price();
	}
	
	
	
	
	public static function get_order() {
		$order = function_exists( 'wc_get_order' ) ? wc_get_order() : false;
		
		if ( ! is_object( $order ) || ! method_exists( $order, 'get_id' ) || ! $order->get_id() ) {
			return self::get_order_thankyou();
		}
		
		return $order;
	}
	
	
	
	
	public static function get_order_thankyou() {
		// Only in thankyou "Order-received" page
		if ( ! is_wc_endpoint_url( 'order-received' ) ) {
			return false;
		}
		
		global $wp;
		
		// Get the order ID
		$order_id = absint( $wp->query_vars['order-received'] );
		
		if ( empty( $order_id ) ) {
			return false;
		}
		
		return wc_get_order( $order_id );
	}
	
	
	
	
	public static function get_order_by_get_params() {
		// check if the order ID exists and if is set the order key
		if ( ! isset( $_GET['order'], $_GET['key'] ) ) {
			return false;
		}
		
		$order_id = (int) $_GET['order'];
		//get order object 
		$order = wc_get_order( $order_id );
		
		//order exists check the order key passed is isset and if it is the same of the order
		$order_key = $order->get_order_key();
		if ( isset( $_GET['key'] ) && $_GET['key'] !== $order_key ) {
			return false;
		}
		
		return $order;
	}
	
	
	
	
	/**
	 * Getting order total price
	 *
	 * @param $_order mixed; order id | order object WP_Post | order object instanceof WC_Abstract_Order
	 *
	 * @return bool|float
	 */
	public static function get_order_value( $_order ) {
		
		$order = function_exists( 'wc_get_order' ) ? wc_get_order( $_order ) : false;
		
		if ( ! is_object( $order ) || ! method_exists( $order, 'get_total' ) ) {
			return false;
		}
		
		return $order->get_total();
	}
	
	
	
	/**
	 * Getting order total price without shipping
	 *
	 * @param $_order mixed; order id | order object WP_Post | order object instanceof WC_Abstract_Order
	 *
	 * @return bool|float
	 */
	public static function get_order_value_no_shipping( $_order ) {
		
		$order = function_exists( 'wc_get_order' ) ? wc_get_order( $_order ) : false;
		
		if (
			! is_object( $order ) ||
			! method_exists( $order, 'get_total' ) ||
			! method_exists( $order, 'get_shipping_total' ) ||
			! method_exists( $order, 'get_shipping_tax' ) ||
			! function_exists( 'wc_get_price_decimals' )
		) {
			return false;
		}
		
		return number_format( (float) $order->get_total() - $order->get_shipping_total() - $order->get_shipping_tax(), wc_get_price_decimals(), '.', '' );
	}
	
	
	
	
	public static function resolve_value_for_inline_js( $value ) {
		$value = (string) $value;
		$value = '' === $value ? '""' : $value;
		$value = is_numeric( $value ) ? $value : "'{$value}'";
		
		return $value;
	}
	
	
	
	
	public static function getShopDomainComputed() {
		$shop_domain = parse_url( home_url(), PHP_URL_HOST );
		$shop_path   = parse_url( home_url(), PHP_URL_PATH );
		$prefix      = 'www.';
		if ( strpos( $shop_domain, $prefix ) === 0 ) {
			$shop_domain = substr( $shop_domain, strlen( $prefix ) );
		}
		
		return str_replace( '/', '_', $shop_domain . $shop_path );
	}
	
	
	
	
	public static function getShopDomainFromOption() {
		return get_option( 'adscale__shop_domain', '' );
	}
	
	
	
	
	public static function getShopDomain() {
		$from_option = self::getShopDomainFromOption();
		$computed    = self::getShopDomainComputed();  // bc
		
		return $from_option ? $from_option : $computed;
	}
	
	
	
	
	public static function saveComputedShopDomain() {
		return update_option( 'adscale__shop_domain', self::getShopDomainComputed() );
	}
	
	
	
	
	public static function getProxyEndpoint() {
		return get_option( 'adscale__proxy_endpoint', '' );
	}
	
	
	
	
	public static function saveDefaultProxyEndpoint() {
		$proxy_from_config = self::getConfigSetting( 'adscale_proxy_url_base', '' );
		
		return update_option( 'adscale__proxy_endpoint', $proxy_from_config );
	}
	
	
	
	
	public static function saveGVCode( $code ) {
		update_option( 'adscale__gsv', $code ); // google-site-verification
	}
	
	
	
	
	public static function getGVCode() {
		return get_option( 'adscale__gsv', '' );
	}
	
	
	
	
	public static function resolveGVCode() {
		if ( ! self::getGVCode() ) {
			API_Manager::process_google_verification_code();
		}
	}
	
	
	
	
	public static function saveFVCode( $code ) {
		update_option( 'adscale__fdv', $code );  // facebook-domain-verification
	}
	
	
	
	
	public static function getFVCode() {
		return get_option( 'adscale__fdv', '' );
	}


    public static function getOptInEnabled(){
        return get_option( 'adscale__optin_enabled')=='on';
    }

    public static function getOptInChecked(){
        $option=get_option(  'adscale__optin_checked_by_default')=='on';

        if (is_user_logged_in()) {
            // date check users if exists field by user
            $optin = get_user_meta(get_current_user_id(), '_adscale__optin_date', true);
            $optout = get_user_meta(get_current_user_id(), '_adscale__optout_date', true);
            if ($optin && $optout) {
                $option = strtotime($optout) < strtotime($optin);
            } elseif ($optout) {
                $option = false;
            } elseif ($optin) {
                $option = true;
            }
        }

        return $option;
    }

    public static function getOptInAction(){
        return get_option( 'adscale__optin_position')?:'woocommerce_review_order_before_submit';
    }

    public static function getOptInMessage(){
        return get_option( 'adscale__optin_message')?:__('I agree to receive marketing materials by sms or email','adscale');
    }
	
	
	public static function resolveFVCode() {
		if ( ! self::getFVCode() ) {
			API_Manager::process_facebook_verification_code();
		}
	}
	
	
	
	
	public static function getConfigSetting( $name, $default, $direct = false ) {
		$parts = explode( '/', $name );
		
		$config = $direct
			? apply_filters( 'adscale/config', require ADSCALE_PLUGIN_DIR . '/src/config/config.php' )
			: App::instance()->getConfig();
		
		if ( ! isset( $config[ $parts[0] ] ) ) {
			return $default;
		}
		
		$value = $config[ array_shift( $parts ) ];
		
		foreach ( $parts as $part ) {
			if ( is_array( $value ) && isset( $value[ $part ] ) ) {
				$value = $value[ $part ];
			} else {
				return $default;
			}
		}
		
		return $value instanceof \Closure ? $value() : $value;
	}
	
	
	
	
	public static function generateRandString( $length = 32 ) {
		$chars          = '123456789ABCDEFGHIJKLMNPQRSTUVWXYZ';
		$chars_length   = strlen( $chars );
		$generatedValue = '';
		
		for ( $i = 1; $i <= $length; ++ $i ) {
			$generatedValue .= substr( $chars, (int) floor( self::randomFloat( 0, 1 ) * ( $chars_length - 1 ) ), 1 );
		}
		
		return $generatedValue;
	}
	
	
	
	
	public static function randomFloat( $min = 0, $max = 1 ) {
		return $min + mt_rand() / mt_getrandmax() * ( $max - $min );
	}
	
	
	
	
	public static function generateRandHash( $limit = 32 ) {
		if ( ! function_exists( 'openssl_random_pseudo_bytes' ) ) {
			return self::generateRandString( $limit );
		}
		
		$bytes = openssl_random_pseudo_bytes( $limit );
		$hex   = strtoupper( bin2hex( $bytes ) );
		
		return substr( $hex, 0, $limit );
	}
	
	
	
	
	public static function getAccessKey() {
		return @hex2bin( self::getPostBodyDataValue( 'key' ) );
	}
	
	
	
	
	public static function getPostBodyDataValue( $key ) {
		$data = json_decode( file_get_contents( 'php://input' ), false );
		
		return isset( $data->$key ) ? $data->$key : null;
	}
	
	
	
	
	public static function delToEnsureRewriteRule( $rewrite_rule_regex ) {
		$rewrite_rules = get_option( 'rewrite_rules' );
		if ( is_array( $rewrite_rules ) && ! array_key_exists( $rewrite_rule_regex, $rewrite_rules ) ) {
			delete_option( 'rewrite_rules' );
		}
	}
	
	
	
	public static function getResolvedActivationEmail() {
		$infoFileEmail = self::getInfoFileEmail();
		
		return $infoFileEmail ? $infoFileEmail : self::getSiteEmail();
	}
	
	
	public static function getSiteEmail() {
		return get_option( 'admin_email' );
	}
	
	
	public static function getInfoFileEmail() {
		return self::getInfoFileValue( 'email_on_download' );
	}
	
	
	public static function getInfoFileValue( $key ) {
		$data = self::getInfoFileData();
		
		return isset( $data[ $key ] ) ? $data[ $key ] : null;
	}
	
	
	public static function getInfoFileData() {
		$infoFilePath = ADSCALE_PLUGIN_DIR . '/info.php';
		
		if ( is_file( $infoFilePath ) ) {
			return include $infoFilePath;
		}
		
		return [];
	}
	
	
	
	public static function getValidModes() {
		return self::getConfigSetting( 'mode/valid', [ 'Full', 'Shopy' ] );
	}
	
	/**
	 * Checking the 'mode' is valid
	 *
	 * @param $mode string
	 *
	 * @return bool
	 */
	public static function isValidMode( $mode ) {
		return in_array( $mode, self::getValidModes(), true );
	}
	
	public static function getDefaultMode() {
		return self::getConfigSetting( 'mode/default', 'Full' );
	}
	
	public static function getModeFromOption() {
		return get_option( 'adscale__mode', '' );
	}
	
	/**
	 * Main getter mode method
	 * return mode from options or default value otherwise
	 */
	public static function getMode() {
		$mode_from_opt = self::getModeFromOption();
		
		return $mode_from_opt && self::isValidMode( $mode_from_opt )
			? $mode_from_opt
			: self::getDefaultMode();
	}
	
	/**
	 * Saving the 'mode' to options if it valid
	 *
	 * @param $mode string
	 *
	 * @return bool true if mode is valid and saved in options, false - otherwise
	 */
	public static function saveMode( $mode ) {
		$valid = self::isValidMode( $mode );
		if ( $valid ) {
			update_option( 'adscale__mode', $mode );
		}
		
		return $valid && get_option( 'adscale__mode' ) === $mode;
	}
	
	public static function getInfoFileMode() {
		return self::getInfoFileValue( 'mode_on_download' );
	}
	
	/**
	 * Return mode from Info File or default value otherwise
	 */
	public static function getResolvedMode() {
		$mode  = self::getInfoFileMode();
		$valid = self::isValidMode( $mode );
		
		return $valid && $mode ? $mode : self::getDefaultMode();
	}
	
	public static function saveResolvedMode() {
		return self::saveMode( self::getResolvedMode() );
	}
	
	/**
	 * Checking the 'mode' is 'Full'
	 *
	 * @return bool
	 */
	public static function isFullMode() {
		return self::getMode() === 'Full';
	}
	
	/**
	 * Checking the 'mode' is 'Shopy'
	 *
	 * @return bool
	 */
	public static function isShopyMode() {
		return self::getMode() === 'Shopy';
	}
	
	
	/**
	 * Checking the need for a redirect to Adscale on plugin activation
	 *
	 * @return bool
	 */
	public static function isNeedRedirectOnActivation() {
		$is_need         = self::getInfoFileValue( 'redirect_on_activation' );
		$is_need_default = true;
		
		return null !== $is_need
			? 1 === (int) $is_need
			: $is_need_default;
	}
	
	
	/**
	 * Format Response with ADSCALE marks
	 *
	 * @param string $response
	 *
	 * @return string
	 */
	public static function formatResponse( $response ) {
		return "ADSCALE_START{$response}ADSCALE_END";
	}
	
	
	
	/**
	 * Send a JSON response, indicating success.
	 *
	 * @param mixed $data Data to encode as JSON, then print and die.
	 * @param int $statusCode
	 * @param string $statusDesc
	 */
	public static function sendResponseJsonSuccess( $data = null, $statusCode = 200, $statusDesc = '' ) {
		self::sendResponseJson( $data, $statusCode, $statusDesc );
	}
	
	
	
	/**
	 * Send a JSON response, indicating failure.
	 *
	 * @param mixed $data Data to encode as JSON, then print and die.
	 * @param int $statusCode The HTTP status code to output.
	 * @param string $statusDesc
	 */
	public static function sendResponseJsonError( $data = null, $statusCode = 500, $statusDesc = '' ) {
		self::sendResponseJson( $data, $statusCode, $statusDesc );
	}
	
	
	
	public static function sendResponseJson( $response, $statusCode = null, $statusDesc = '' ) {
		self::sendResponse( json_encode( $response ), $statusCode, $statusDesc, 'application/json' );
	}
	
	
	
	/**
	 * Send a Formatted response, indicating success.
	 *
	 * @param mixed $data Data to encode as JSON, then print and die.
	 * @param int $statusCode
	 * @param string $statusDesc
	 */
	public static function sendResponseFormattedSuccess( $data = null, $statusCode = 200, $statusDesc = '' ) {
		self::sendResponseFormatted( $data, $statusCode, $statusDesc );
	}
	
	
	
	/**
	 * Send a Formatted response, indicating failure.
	 *
	 * @param mixed $data Data to encode as JSON, then print and die.
	 * @param int $statusCode The HTTP status code to output.
	 * @param string $statusDesc
	 */
	public static function sendResponseFormattedError( $data = null, $statusCode = 500, $statusDesc = '' ) {
		self::sendResponseFormatted( $data, $statusCode, $statusDesc );
	}
	
	
	
	public static function sendResponseFormatted( $response, $statusCode = null, $statusDesc = '' ) {
		self::sendResponse( self::formatResponse( json_encode( $response ) ), $statusCode, $statusDesc, 'text/plain' );
	}
	
	
	
	public static function sendResponse( $response, $statusCode = null, $statusDesc = '', $contentType = 'text/plain' ) {
		if ( ! headers_sent() ) {
			if ( null !== $statusCode ) {
				\remove_all_filters( 'status_header', false );
				\status_header( $statusCode, $statusDesc );
			}
			if ( is_string( $contentType ) && $contentType ) {
				header( "Content-Type: {$contentType}" );
			}
		}
		
		echo wp_kses( $response, self::getResponseAllowedHtmlTags() );
		die();
	}
	
	
	public static function getResponseAllowedHtmlTags() {
		return self::getConfigSetting( 'response_allowed_html_tags', [] );
	}
	
	
	
	/**
	 * Set a cookie - wrapper for setcookie using WP constants.
	 *
	 * @param string $name Name of the cookie being set.
	 * @param string $value Value of the cookie.
	 * @param integer $expire Expiry of the cookie.
	 * @param bool $secure Whether the cookie should be served only over https.
	 * @param bool $httponly Whether the cookie is only accessible over HTTP, not scripting languages like JavaScript.
	 */
	public static function setCookie( $name, $value, $expire = 0, $secure = false, $httponly = false ) {
		if ( ! headers_sent() ) {
			setcookie( $name, $value, $expire, COOKIEPATH ? COOKIEPATH : '/', COOKIE_DOMAIN, $secure, $httponly );
			//Logger::log( "name [{$name}], value [{$value}]", 'setCookie: success: ', 'cookie' );
		} else {
			headers_sent( $file, $line );
			Logger::log( "{$name} cookie cannot be set - headers already sent by {$file} on line {$line}", 'setCookie: failed: ', 'cookie' );
		}
	}
	
	
	
	/**
	 * Gets WC Session cookie - Contains a unique code for each customer
	 * so that it knows where to find the cart data in the database for each customer.
	 *
	 * @return string
	 */
	public static function getWCSessionCookieRestoredValue() {
		$wc_session_cookie_parts = WC()->session->get_session_cookie();
		
		return is_array( $wc_session_cookie_parts )
			? rawurlencode( implode( '||', $wc_session_cookie_parts ) )
			: '';
	}
	
	
	
	
	public static function getArrayValue( $array, $key, $default = null, $cb = null ) {
		if ( ! isset( $array[ $key ] ) ) {
			return $default;
		}
		
		return is_callable( $cb ) ? $cb( $array[ $key ] ) : $array[ $key ];
	}
	
	
	
	
	public static function getObjProperty( $obj, $prop, $default = null, $cb = null ) {
		if ( ! isset( $obj->$prop ) ) {
			return $default;
		}
		
		return is_callable( $cb ) ? $cb( $obj->$prop ) : $obj->$prop;
	}
	
	
	
	
	public static function nocacheHeaders() {
		if ( function_exists( 'wc_nocache_headers' ) ) {
			wc_nocache_headers();
		} else {
			nocache_headers();
		}
	}
	
	
	
	
	public static function getAdscaleAdLink() {
		return self::getArrayValue( $_COOKIE, 'adscale_ad_link' );
	}



    public static function getAdscaleOptIn() {
        return self::getArrayValue( $_COOKIE, 'adscale__optin' );
    }
	
	
	/**
	 * Get saved adscale_ad_link
	 *
	 * @param int $order_id
	 *
	 * @return string
	 */
	public static function getSavedAdscaleAdLink( $order_id ) {
		return (string) get_post_meta( $order_id, '_adscale_ad_link', true );
	}
	
	
	
	
	public static function getWcPermalinkStructure() {
		$saved_permalinks = (array) get_option( 'woocommerce_permalinks', array() );
		$permalinks       = wp_parse_args(
			array_filter( $saved_permalinks ),
			array(
				'product_base'           => _x( 'product', 'slug', 'woocommerce' ),
				'category_base'          => _x( 'product-category', 'slug', 'woocommerce' ),
				'tag_base'               => _x( 'product-tag', 'slug', 'woocommerce' ),
				'attribute_base'         => '',
				'use_verbose_page_rules' => false,
			)
		);
		
		$permalinks['product_rewrite_slug']   = untrailingslashit( $permalinks['product_base'] );
		$permalinks['category_rewrite_slug']  = untrailingslashit( $permalinks['category_base'] );
		$permalinks['tag_rewrite_slug']       = untrailingslashit( $permalinks['tag_base'] );
		$permalinks['attribute_rewrite_slug'] = untrailingslashit( $permalinks['attribute_base'] );
		
		return $permalinks;
	}
	
	
	
	
	public static function saveDefaultConsiderPendingOrders() {
		$default_from_config = self::getConfigSetting( 'default_consider_pending_orders', true );
		
		return update_option( 'adscale__consider_pending_orders', $default_from_config );
	}
	
	
	
	
	public static function isConsiderPendingOrders() {
		return filter_var( get_option( 'adscale__consider_pending_orders', false ), FILTER_VALIDATE_BOOLEAN );
	}
	
	
	
	
	/**
	 * Analog of WordPress function wp_timezone_string for wp<5.3 compatibility
	 */
	public static function wp_timezone_string() {
		$timezone_string = get_option( 'timezone_string' );
		
		if ( $timezone_string ) {
			return $timezone_string;
		}
		
		$offset  = (float) get_option( 'gmt_offset' );
		$hours   = (int) $offset;
		$minutes = ( $offset - $hours );
		
		$sign      = ( $offset < 0 ) ? '-' : '+';
		$abs_hour  = abs( $hours );
		$abs_mins  = abs( $minutes * 60 );
		$tz_offset = sprintf( '%s%02d:%02d', $sign, $abs_hour, $abs_mins );
		
		return $tz_offset;
	}
	
	
	
	public static function getCurrentHttpMethod() {
		return isset( $_SERVER['REQUEST_METHOD'] ) ? strtoupper( sanitize_text_field( $_SERVER['REQUEST_METHOD'] ) ) : '';
	}
	
	
	
	/**
	 * Float formatting
	 *
	 * @param float|int $val
	 * @param int $precision
	 * @param int $mode
	 *
	 * @return string
	 */
	public static function formatPriceWithPrecision( $val, $precision = 2, $mode = PHP_ROUND_HALF_UP ) {
		$val = (float) $val;
		$val = round( $val, $precision, $mode );
		
		return number_format( $val, $precision, '.', '' );
	}
	
	
	
	/**
	 * Validate Date
	 *
	 * @param string $date
	 * @param string $format
	 *
	 * @return bool
	 */
	public static function validateDate( $date, $format = 'Y-m-d H:i:s' ) {
		$d = \DateTime::createFromFormat( $format, $date );
		
		return $d && $d->format( $format ) === $date;
	}
	
	
	
	/**
	 * Reformat Date
	 *
	 * @param string $date
	 * @param string $format_from
	 * @param string $format_to
	 *
	 * @return bool|string
	 */
	public static function reformatDate( $date, $format_from = 'dmY', $format_to = 'Y-m-d' ) {
		$d = \DateTime::createFromFormat( $format_from, $date );
		
		return $d ? $d->format( $format_to ) : false;
	}
	
	
	
	/**
	 * Return true if Id Valid, else - false
	 *
	 * @param int|string $id
	 *
	 * @return bool
	 */
	public static function checkIdIsValid( $id ) {
		return is_numeric( $id ) && $id && (string) abs( (int) $id ) === (string) $id;
	}
	
	
	
	/**
	 * Get full continent name
	 *
	 * @param string $cc Continent code ('EU, SA, ...')
	 *
	 * @return string
	 */
	public static function getFullContinentName( $cc ) {
		if ( ! $cc ) {
			return $cc;
		}
		
		$continent = self::getArrayValue( WC()->countries->get_continents(), $cc, [] );
		
		return self::getArrayValue( $continent, 'name', $cc );
	}
	
	
	
	/**
	 * Get full list of countries of the continent
	 *
	 * @param string $cc Continent code ('EU, SA, ...')
	 * @param bool $code_to_name
	 *
	 * @return array
	 */
	public static function getContinentCountries( $cc, $code_to_name = false ) {
		if ( ! $cc ) {
			return [];
		}
		
		$continent = self::getArrayValue( WC()->countries->get_continents(), $cc, [] );
		
		$continent_countries_codes = self::getArrayValue( $continent, 'countries', [] );
		
		if ( ! $code_to_name ) {
			return $continent_countries_codes;
		}
		
		$all_countries = WC()->countries->get_countries();
		
		$continent_countries_names = [];
		foreach ( $continent_countries_codes as $code ) {
			$continent_countries_names[] = self::getArrayValue( $all_countries, $code, $code );
		}
		
		return $continent_countries_names;
	}
	
	
	
	/**
	 * Get full country name
	 *
	 * @param string $cc Country code ('US, GB, ...')
	 *
	 * @return string
	 */
	public static function getFullCountryName( $cc ) {
		if ( ! $cc ) {
			return $cc;
		}
		
		return self::getArrayValue( WC()->countries->get_countries(), $cc, $cc );
	}
	
	
	
	/**
	 * Get full state name
	 *
	 * @param string $country Country code ('US, GB, ...')
	 * @param string $state State code ('CA, FL, ...')
	 *
	 * @return string
	 */
	public static function getFullStateName( $country, $state ) {
		if ( ! $country || ! $state ) {
			return $state;
		}
		$states = WC()->countries->get_states( $country );
		
		return self::getArrayValue( $states, $state, $state );
	}
	
	
	
	
	public static function validateSecKey( $key ) {
		
		if ( ! class_exists( '\Adscale_Crypt_RSA' ) ) {
			$libPath = ADSCALE_PLUGIN_DIR . '/lib/customized/vendor/phpseclib';
			set_include_path( get_include_path() . PATH_SEPARATOR . $libPath );
			require_once 'AdscaleCrypt/RSA.php';
		}
		
		$rsa = new \Adscale_Crypt_RSA();
		$rsa->setSignatureMode( ADSCALE_CRYPT_RSA_SIGNATURE_PKCS1 );
		$rsa->setEncryptionMode( ADSCALE_CRYPT_RSA_ENCRYPTION_PKCS1 );
		
		$rsa->loadKey( "-----BEGIN PUBLIC KEY-----\nMIGfMA0GCSqGSIb3DQEBAQUAA4GNADCBiQKBgQCBMUfDGyQbPrNjBpZVkQ6Kabt4fo9W0fRlA7XKdbo2eg9P8i+TfBfeYBd6hlu/DlMnDL8AdElXKakNONT5B4y1/M15cBySmn1gDPLYs/u9rZrjmGLNZX/4sOomISUFihnDl2+3hGMrrGRQyuW78kY/ZJBpdqqybAJolJTe1J4R2wIDAQAB\n-----END PUBLIC KEY-----" );
		
		// return '1111' === $key || hex2bin( '1111' ) === $key; // for testing
		
		return @$rsa->verify( self::getShopDomain(), $key );
	}
}
