<?php

namespace AdScale\PluginApi;

use AdScale\Helpers\Helper;

defined( 'ABSPATH' ) || exit; // Exit if accessed directly


class CategoriesCount extends PluginApiBase {
	
	protected static $defaultIds = [];
	
	
	public static function initContent() {
		global $wp;
		
		if ( isset( $_GET['adscaleCategoriesCount'] ) ) {
			$wp->query_vars['adscaleCategoriesCount'] = sanitize_key( wp_unslash( $_GET['adscaleCategoriesCount'] ) );
		}
		
		//  make sure endpoint request
		if ( ! isset( $wp->query_vars['adscaleCategoriesCount'] ) ) {
			return;
		}
		
		
		try {
			ob_start();
			
			// Error handler
			self::setErrorHandler();
			
			Helper::nocacheHeaders();
			
			// Check Request (Guards)
			self::checkRequest();
			
			ob_end_clean();
			
			// Handle Request
			self::handleRequest();
			
			// Default error
			Helper::sendResponseFormattedError( self::makeErrorBody() );
		} catch ( PluginApiException $ex ) {
			Helper::sendResponseFormattedError(
				self::makeErrorBody( $ex->getApiErrorCode(), $ex->getMessage(), $ex->getApiErrorDetails() )
			);
		} catch ( \Exception $ex ) {
			Helper::sendResponseFormattedError( self::makeErrorBody( $ex->getCode(), $ex->getMessage() ) );
		}
	}
	
	
	/**
	 * Handle API request
	 *
	 * @throws PluginApiException
	 */
	public static function handleRequest() {
		$args = [
			'taxonomy'   => [ 'product_cat' ],
			'hide_empty' => false,
			'fields'     => 'count',
		];
		
		$terms_count = get_terms( $args );
		
		if ( is_wp_error( $terms_count ) ) {
			throw new PluginApiException( 'Unknown error', 'S000', 'A product categories count error' );
		}
		
		Helper::sendResponseFormattedSuccess( [ 'count' => (int) $terms_count, ] );
	}
}
