<?php

namespace AdScale\PluginApi;

use AdScale\Helpers\Helper;

defined( 'ABSPATH' ) || exit; // Exit if accessed directly


class ProductsCount extends PluginApiBase {
	
	
	public static function initContent() {
		global $wp;
		
		if ( isset( $_GET['adscaleProductsCount'] ) ) {
			$wp->query_vars['adscaleProductsCount'] = sanitize_key( wp_unslash( $_GET['adscaleProductsCount'] ) );
		}
		
		//  make sure endpoint request
		if ( ! isset( $wp->query_vars['adscaleProductsCount'] ) ) {
			return;
		}
		
		
		try {
			ob_start();
			
			// Error handler
			self::setErrorHandler();
			
			Helper::nocacheHeaders();
			
			// Check Request (Guards)
			self::checkRequest();
			
			ob_end_clean();
			
			// Handle Request
			self::handleRequest();
			
			// Default error
			Helper::sendResponseFormattedError( self::makeErrorBody() );
		} catch ( PluginApiException $ex ) {
			Helper::sendResponseFormattedError(
				self::makeErrorBody( $ex->getApiErrorCode(), $ex->getMessage(), $ex->getApiErrorDetails() )
			);
		} catch ( \Exception $ex ) {
			Helper::sendResponseFormattedError( self::makeErrorBody( $ex->getCode(), $ex->getMessage() ) );
		}
	}
	
	
	/**
	 * Handle API request
	 *
	 * @throws PluginApiException
	 */
	public static function handleRequest() {
		$args = [
			'status'  => [ 'private', 'publish' ],
			'limit'   => - 1,
			'orderby' => 'ID',
			'order'   => 'ASC',
			'return'  => 'ids',
		];
		
		$products_ids = wc_get_products( $args );
		
		if ( ! is_array( $products_ids ) ) {
			throw new PluginApiException( 'Unknown error', 'S000', 'Products count error' );
		}
		
		Helper::sendResponseFormattedSuccess( [ 'count' => count( $products_ids ), ] );
	}
}
