<?php

namespace AdScale\ServiceApi;

use AdScale\Handlers\Status as StatusHandler;
use AdScale\Helpers\Helper;

defined( 'ABSPATH' ) || exit; // Exit if accessed directly


class Status extends ServiceApiBase {
	
	public static function initContent() {
		global $wp;
		
		if ( isset( $_GET['adscaleStatus'] ) ) {
			$wp->query_vars['adscaleStatus'] = sanitize_key( wp_unslash( $_GET['adscaleStatus'] ) );
		}
		
		//  make sure endpoint request
		if ( ! isset( $wp->query_vars['adscaleStatus'] ) ) {
			return;
		}
		
		
		try {
			ob_start();
			
			Helper::nocacheHeaders();
			
			// Check Request (Guards)
			self::checkRequest();
			
			ob_end_clean();
			
			// Handle Request
			self::handleRequest();
			
			// Default error
			Helper::sendResponseFormattedError( self::makeErrorBody() );
		} catch ( ServiceApiException $ex ) {
			Helper::sendResponseFormattedError(
				self::makeErrorBody( $ex->getApiErrorCode(), $ex->getMessage(), $ex->getApiErrorDetails() )
			);
		} catch ( \Exception $ex ) {
			Helper::sendResponseFormattedError( self::makeErrorBody( $ex->getCode(), $ex->getMessage() ) );
		}
	}
	
	
	
	public static function handleRequest() {
		$statusData = StatusHandler::getStatusData();
		
		$is_format_json_by_post_body = strtoupper( Helper::getPostBodyDataValue( 'format' ) ) === 'JSON';
		
		$is_format_json_by_get = isset( $_GET['format'] ) &&
								 strtoupper( sanitize_text_field( wp_unslash( $_GET['format'] ) ) ) === 'JSON';
		
		$is_format_json = $is_format_json_by_post_body || $is_format_json_by_get;
		
		if ( $is_format_json ) {
			$response = StatusHandler::renderDataToJson( $statusData );
			Helper::sendResponse( Helper::formatResponse( $response ), 200, '', 'text/plain' );
		} else {
			$response = StatusHandler::renderDataToHtml( $statusData );
			Helper::sendResponse( Helper::formatResponse( $response ), 200, '', 'text/html' );
		}
	}
}
